@@ -2,7 +2,7 @@ DirichReg <- function(formula,
                       data,
                       model = c("common", "alternative"),
                       subset,
-                      sub.comp,                                                
+                      sub.comp,                                                 # subcompositions
                       base,
                       weights,
                       control,
@@ -22,7 +22,7 @@ if(verbosity > 0){
   if(interactive()) flush.console()
 }
 
- 
+  # checks and preliminary work
   if(missing(data)) data <- environment(formula)
 
   if(missing(formula)){
@@ -40,22 +40,22 @@ if(verbosity > 0){
     if(is.null(control$tol2))    control$tol2     <- .Machine$double.eps^(3/4)
   }
 
-
+#>>> get Y #####################################################################
   resp_lang <- oformula[[2L]]
   resp_char <- deparse(resp_lang)
 
-  has_data    <- !missing(data)                                                
-  Y_in_data   <- ifelse(has_data, resp_char %in% names(data), FALSE)  
-  has_DR_call <- grepl("DR_data", resp_char, fixed = TRUE)            
+  has_data    <- !missing(data)                                                 # "data" defined?
+  Y_in_data   <- ifelse(has_data, resp_char %in% names(data), FALSE)   # response in data
+  has_DR_call <- grepl("DR_data", resp_char, fixed = TRUE)             # on the fly transformation?
 
   if(Y_in_data){
-    Y_full <- data[[resp_char]]                                                
+    Y_full <- data[[resp_char]]                                                 # get response from "data"
   } else if(has_DR_call){
-    Y_full <- eval(resp_lang)                                                  
+    Y_full <- eval(resp_lang)                                                   # get response from an on the fly transformation --- NOT recommended
     warning(paste0(strwrap("The response was transformed by DR_data() on the fly. This is not recommended, consider adapting your code.", width = getOption("width") - 9L, exdent = 9L), collapse = "\n"), call. = FALSE, immediate. = TRUE)
     oformula[[2L]] <- as.symbol("Y_full")
   } else {
-    Y_full <- get(resp_char, environment(oformula))                            
+    Y_full <- get(resp_char, environment(oformula))                             # get response from the parent frame
   }
   formula <- as.Formula(oformula)
 
@@ -69,24 +69,24 @@ if(verbosity > 0){
 
 
 
+#  if(ifelse(!missing(data), deparse(oformula[[2]]) %in% names(data), FALSE)){
+#    Y_full <- data[[deparse(oformula[[2]])]]                                    # GET THE FULL DRData OBJECT FOR INFORMATIONS (Y_full)
+#  } else {                                                                      # handle responses in .GlobalEnv
+#    Y_full <- get(deparse(oformula[[2]]), environment(oformula))
+#    if(missing(data)){
+#      data[[deparse(oformula[[2]])]] <- Y_full
+#    } else {
+#      assign(deparse(oformula[[2]]), Y_full)
+#    }
+#  }
+#  if(class(Y_full) != "DirichletRegData") stop("the response must be prepared by DR_data")
 
-
-
-
-
-
-
-
-
-
-
-
-
+#<<< get Y #####################################################################
 
   repar <- ifelse(model == "common", FALSE, TRUE)
 
   mf <- match.call(expand.dots = FALSE)
-
+# if response was produced by DR_data()
   if(has_DR_call){
     mf[["formula"]][[2L]] <- as.symbol("Y_full")
   }
@@ -104,7 +104,7 @@ if(verbosity > 0){
 
 
 
-
+## SUBCOMPOSITIONS
   if(missing(sub.comp)){
     sub.comp <- seq_len(ncol(Y))
   } else {
@@ -124,13 +124,13 @@ if(verbosity > 0){
 
   n.dim <- ncol(Y)
 
-
+## SANITY CHECKS AND FORMULA EXPANSION
   if(length(formula)[1] != 1) stop("the left hand side of the model must contain one object prepared by DR_data()")
 
-  if(!repar){  
+  if(!repar){   # COMMON
     if(length(formula)[2] == 1) for(i in 2:ncol(Y)) attr(formula, "rhs") <- lapply(seq_len(ncol(Y)), function(i) attr(formula, "rhs")[[1]])
     if(length(formula)[2] > ncol(Y)) stop("the right hand side must contain specifications for either one or all variables")
-  } else {  
+  } else {   # ALTERNATIVE
     if(length(formula)[2] == 1) formula <- as.Formula(formula(formula), ~ 1)
     if(length(formula)[2] > 2) stop("the right hand side can only contain one or two specifications in the alternative parametrization")
   }
@@ -146,17 +146,17 @@ if(verbosity > 0){
     n.vars <- c(unlist(lapply(X.mats, ncol))[-1], ncol(Z.mat))
   }
 
+################################################################################
+### simplify and typecast variables ############################################
+################################################################################
 
-
-
-
- 
+  # simplify dependent variable
   Y_fit <- unclass(Y)
   attributes(Y_fit) <- NULL
   dim(Y_fit) <- dim(Y)
   storage.mode(Y_fit) <- "double"
 
- 
+  ### typecasting
   X_fit <- lapply(X.mats, function(this_mat){
     attr(this_mat, "dimnames") <- NULL
     attr(this_mat, "assign") <- NULL
@@ -177,7 +177,7 @@ if(verbosity > 0){
   if(interactive()) flush.console()
 }
 
- 
+  # compute starting values
   if(is.null(control$sv)){
     starting.vals <- get_starting_values(Y=Y_fit, X.mats=X_fit,
                        Z.mat={if(repar) as.matrix(Z.mat) else Z.mat},
@@ -194,7 +194,7 @@ if(verbosity > 0){
   if(interactive()) flush.console()
 }
 
- 
+  # fit and store the results
   fit.res <- DirichReg_fit(Y     = Y_fit,
                            X     = X_fit,
                            Z     = as.matrix(Z.mat),
@@ -219,7 +219,7 @@ if(verbosity > 0){
   }
 
 
- 
+  # FITTED VALUES
   if(repar){
 
     B <- matrix(0.0, nrow = n.vars[1L], ncol = n.dim)
@@ -254,9 +254,9 @@ if(verbosity > 0){
                    error=function(x){ return(matrix(NA, nrow=nrow(hessian), ncol=ncol(hessian))) },
                    silent=TRUE)
 
-  if(!repar){  
+  if(!repar){   ## COMMON
     coefnames <- apply(cbind(rep(varnames, n.vars), unlist(lapply(X.mats, colnames))), 1, paste, collapse=":")
-  } else {  
+  } else {   ## ALTERNATIVE
     coefnames <- apply(cbind(rep(c(varnames[-base], "(phi)"), n.vars), c(unlist(lapply(X.mats, colnames)[-base]), colnames(Z.mat))), 1, paste, collapse=":")
   }
 
@@ -299,14 +299,14 @@ if(verbosity > 0){
   ),
   class = "DirichletRegModel")
 
- 
+  # remove stuff from maxLik in the parent frame
   for(maxLik_ob in c("lastFuncGrad", "lastFuncParam")){
     if(exists(maxLik_ob, envir = parent.frame(), inherits = FALSE)) rm(list = maxLik_ob, envir = parent.frame(), inherits = FALSE)
   }
- 
+  # ... clean up the mess ...
   used_objects <- ls(all.names = TRUE)
   rm(list = c("used_objects", used_objects[used_objects != "res"]))
- 
+  # ... and make some space
   on.exit(gc(verbose = FALSE, reset = TRUE), add = TRUE)
 
   return(res)
